# Glean Sample Application

A simple app showcasing the Glean SDK.

## Running tests

1. [Setup the Android Build Environment](https://mozilla.github.io/glean/book/dev/android/setup-android-build-environment.html?highlight=android#setup-the-android-build-environment)
2. Run `./gradlew :glean-sample-app:connectedAndroidTest`

Since the tests are instrumented they need a connected device or emulator
present to complete.

## License

    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/
